import os
from typing import Dict, List

from azure.ai.textanalytics import TextAnalyticsClient
from azure.core.credentials import AzureKeyCredential

from xraygpt.splitter import sillySplit


def recognize_entities(reviews: List[str]) -> None:
    endpoint = os.environ["AZURE_LANGUAGE_ENDPOINT"]
    key = os.environ["AZURE_LANGUAGE_KEY"]

    text_analytics_client = TextAnalyticsClient(
        endpoint=endpoint, credential=AzureKeyCredential(key)
    )

    reviews = sillySplit(reviews, 5000)
    result_raw = [text_analytics_client.recognize_entities([r])[0] for r in reviews]
    result = [review for review in result_raw if not review.is_error]
    result_error = [review for review in result_raw if review.is_error]
    for error in result_error:
        print("Error: ", error["error"])
    related_to_reviews: Dict[str, List[str]] = {}

    for idx, review in enumerate(result):
        for entity in review.entities:
            print(f"Entity '{entity.text}' has category '{entity.category}'")
            related_to_reviews.setdefault(entity.text, [])
            related_to_reviews[entity.text].append(reviews[idx])


if __name__ == "__main__":
    reviews = [
        """I work for Foo Company, and we hired Contoso for our annual founding ceremony. The food
        was amazing and we all can't say enough good words about the quality and the level of service.""",
        """We at the Foo Company re-hired Contoso after all of our past successes with the company.
        Though the food was still great, I feel there has been a quality drop since their last time
        catering for us. Is anyone else running into the same problem?""",
        """Bar Company is over the moon about the service we received from Contoso, the best sliders ever!!!!""",
    ]
    recognize_entities(reviews)



from xraygpt.ner import recognize_entities
from xraygpt.reader import EPubReader


def epubSummaryFlow(filename):
    for item in EPubReader(filename):
        print(item)
        recognize_entities([item])
        break


if __name__ == "__main__":
    print(epubSummaryFlow("workdir/InfiniteJest.epub"))



from os import environ

from langchain_openai import AzureChatOpenAI, ChatOpenAI
from loguru import logger


def get_llm() -> ChatOpenAI:
    common_openai_params = {
        "temperature": 0,
        "api_key": environ["OPENAI_API_KEY"],
        "api_version": environ.get("OPENAI_API_VERSION", "2020-05-03"),
    }
    model_id = "chatgpt"
    llm: ChatOpenAI
    if "AZURE_OPENAI_ENDPOINT" in environ:
        logger.info(f"Using AzureOpenAI {model_id}")
        llm = AzureChatOpenAI(
            azure_endpoint=environ["AZURE_OPENAI_ENDPOINT"],
            deployment_name=model_id,
            **common_openai_params,  # type: ignore[arg-type,call-arg]
        )
    else:
        logger.info(f"Using OpenAI {model_id}")
        llm = ChatOpenAI(
            model=model_id,
            **common_openai_params,  # type: ignore[arg-type]
        )
    return llm



import itertools
from typing import List


def sillySplit(strs: List[str], max_len) -> List[str]:
    return [
        i
        for i in itertools.chain.from_iterable([s.split(".") for s in strs])
        if len(i) > 0
    ]
